@@ -1,5 +1,6 @@
 mod alter_row;
 mod alter_table;
+mod create;
 mod execute;
 mod fetch;
 mod other;
@@ -12,6 +13,7 @@ mod types;
 pub use {
 	alter_row::ValidateError,
 	alter_table::AlterError,
+	create::*,
 	execute::{ExecuteError, Payload},
 	fetch::FetchError,
 	query::{JoinError, ManualError, PlanError, QueryError, SelectError},
